---
title: "Communication Urgency"
date: 2022-11-13T13:49:15-08:00
tags:
  - productivity
  - communication
  - information-management

---
**Thesis statement:** *Most communication is less urgent than you think. Encoding urgency into messages as (meta)data is valuable - but building a healthy culture around and relationship with communication urgency is even more so.*
<!--more-->
## Encoding urgency

Starting with the second point - I realized today that no mobile messaging app that I use[^apps-i-use] has the ability to encode "urgency" into the metadata of a message - either tagging a message as "silent", such that it won't trigger a notification on the recipient's device, or as "urgent" such that it is more likely to trigger a notification[^not-overriding]. As a person with friends on both sides of the Atlantic (and someone with a pretty irregular sleep cycle), I'm often messaging someone at a time that they might be asleep. In situations like these, I don't want my message to create a notification and disturb their sleep - but I do want them to get the message if they're awake. Conversely, if I'm in trouble for some reason, I know that my partner or trusted friends would be _distraught_ if their "Do Not Disturb" led to them being unable to help me.

"_But your recipients can just put their phone on silent_" - they can, but some people choose not to. In particular, I know that both my partner and my mother have my number set up to override silent settings - whenever I message them, no matter what, it will always play a notification. Like I said above - there might be an emergency, and in their evaluation it's preferable to be contactable in those situations even if it means disturbed sleep at other times when I forget and message them during (their) night-time.

There was a feature request for this in Signal [here](https://github.com/signalapp/Signal-Android/issues/1803), but sadly it was closed without action. I might re-open it (especially now that [Telegram has it](https://telegram.org/blog/silent-messages-slow-mode)[^telegram-does]) and see if their opinion has changed. **EDIT:** they've moved feature requests to a different location, and it's [already open there](https://community.signalusers.org/t/silent-low-priority-messages-to-avoid-disturbing-the-receiver-silent-messages/2532/43).

## Most communication is less urgent than you think[^only-professional-comms]

The norm in business appears to be that everyone should be kept informed of everything, always. This is untenable. We simply cannot meaningfully ingest and process that volume of information, let alone do anything useful with it, _let alone_ carry out our own work (that we then need to communicate about to everyone else...) with our remaining time and energy. When I was still In Employment, even with some pretty stringent email filters to reduce the noise, I still found that I could have spent the majority of my time working in Outlook. I had a hard enough time getting out of Word and into my IDE, but this was even worse!

Oddly enough, the inspiration for how to address this arose from Napoleon. [Apparently](https://thesweetsetup.com/email-lessons-from-napoleon/), his communication strategy (which, let us not forget, probably dealt with a great volume _and_ importance of communication than any of us!) boiled down to "_Wait three weeks before opening any letter. Either it's unimportant (in which case by that point I can simply discard it and not be distracted), or it's important (in which case, by that time I will have heard about it through other means)_". **This is genius**. I didn't go to quite these extremes (which might have been "career-limiting", shall we say) - but I did adapt it into two productive habits:
* Check email first thing in the morning, and then keep it closed for the rest of the day to maintain focus. If people need me urgently during that time, they'll find me.
* Don't feel the need to jump in or get involved on the first mention of a person demanding your time or attention[^no-really-only-professional-comms], especially if there are other people on the thread that you know are equipped to solve the problem, join the committee, work on the presentation, etc. Let it stew. If a few days go by and there's still interest/demand, you'll see a follow-up email, and you can jump on it then _if_ you're interested - but if it was always going to fizzle out, you haven't wasted time getting ramped up on a non-starter.
  * This one takes some judgement. Being seen to respond quickly, authoritatively, and helpfully to requests from senior management can be a big boost at promo time. Balance your desire to be _truly_ productive, with your desire to be _seen to be_ productive. There's no shame in getting that money!
  * Tangentially, I believe that promotion-culture is also part of the reason for this chronic over-communication. If you are sending an email every week talking about the amazing progress that you and your team have made, you're cementing your name in your management chain's mind. You are, essentially, advertizing yourself. Once again, corporatism and Promotion Driven Development distort actual "productivity" into "playing the game".

Relatedly, my [out-of-office reply](https://www.theladders.com/career-advice/the-only-out-of-office-autoreply-you-need) - stating that I would delete all emails received over that time, and that senders should resend the message on my return date if they still need me - raised some eyebrows, but I strongly believe it's a healthy habit that should be copied. Think back to the last time that you returned to work from a long break and spent hours (days, in some cases) reading back through your received email. How often did you find something _truly_ important, that wouldn't have come up in your next one-to-one with the appropriate person[^one-to-ones] or project status update?

Note that Napoleon's strategy and mine are both complemented by the concept of "message urgency" from the first section. If a general had something _really truly urgent_ to communicate, and the only method of communication he had was sending a letter, then he's screwed - sending a follow-up letter would just get stuck in the same delay trap. My examples rely on the fact that I knew that, if a system was actually crashing and needed my attention, I would get paged - an "escape-hatch" on my attention-preserving strategy. I relied on the fact that there was a strong cultural norm against sending unnecessary pages (so, if my pager went off, I could trust that it was important) - and communication-culture is something I'll explore in the next section.

## A healthy culture around communication is important

One hill I tend to die on[^email-culture] is the misapprehension that "send later" is a helpful feature of messaging clients (including email). **IT IS NOT**, and I feel so strongly about this that I had to go and make a flowchart to explain it:

![Don't Delay Your Email!](/img/DontDelayYourEmail.drawio.png "I've used \"email\" here, but this applies just as well to Slack and other similar systems")

There is no situation in which sending your email with a delay makes any positive impact, and there is a situation (the recipient has some urgent issue or problem during out-of-office hours that your email could have helped with) where it makes a negative impact. Not to mention the (small, but non-zero) cognitive load that the sender has to expend remembering timezones[^timezone-adaptation] and whether this should be delayed or not[^not-hypocritical].

"_But Jack,_" so the counter-argument goes, "_you're committing the classic engineer fallacy of only considering the systematic mechanical interactions, and forgetting the personal and political! If a subordinate receives an email from their superior while out-of-office, they feel pressured to reply to it! Sending emails during out-of-office times is putting unfair pressure on recipients to reply!_". To which I say.........._seriously_?
* First of all, why are you checking your work email while not working? Look up what a Work-Life Balance is, and get one! Don't let work consume your life - work hard and focus while working, but leave it behind when you're not! Did you know that the French [passed a law making it illegal for businesses to require their employees to be available for work-related communication outside designated work hours](https://mymodernmet.com/french-law-bans-workplace-communication-after-work-hours/)?
* Secondly, even if through some odd confluence of situations you happen to become aware of a work email outside of work time, why do you feel pressure to reply to it? Either your boss understands that personal time is personal time, and that they only have a right to your time when you're being paid for it[^overtime-exists]; or they don't understand that, in which case you should be using your spare time to _look for another position_. And if you're a manager who believes that such a culture exists in your team, then you'd damn sure better be doing your best to oppose it by including an email signature stating that you only expect replies during work hours, and actively checking up on anyone who replies outside work hours to make sure they knew it wasn't expected.

So - the problem isn't the email timing, it's the culture. If your work culture expects that emails will only be read and replied to within work hours, then everything becomes simpler and easier - you can send whenever you want, without worry that you'll be pressuring someone. If your work culture expects emails to be replied to immediately 24/7, then the time and energy you spend piddling about with "Send Later" would be better spent on changing that culture to something healthier.

There's a broader point here - about how different people have different ideas of what's important, and you should ensure that your communication culture neither inundates people with information nor withholds it from them when they seek it[^write-shit-down] - but I've already spent 2 hours on what started as just a brief observation about app functionality, and I should wrap this up. Maybe another time.

[^apps-i-use]: Signal/WhatsApp/Messenger/SMS - though I'm gradually migrating conversations off the others and onto Signal
[^telegram-does]: I've never used Telegram - I'd got the impression that it's basically "_Signal, but less secure_", and if I was going to spend my social capital to convince my family and non-techie friends to adopt a new app, I was sure as hell going to pick the most secure one. Maybe I should check it out...
[^not-overriding]: To be clear, this isn't a request to override a recipient's preferences. If they absolutely positively want no notifications at all, they should be able to set that - and, likewise, if they really truly want to get a notification for every message I send, that's their prerogative. This is giving an _extra dimension_ on which they can set their preferences ("_notify me for every non-silent message Jack sends_") - which, as I lay out above, covers some reasonable use-cases. In particular - I think the _default_ behaviour for "urgent" messages should still be whatever your system default behaviour is (silent if you have silent mode on, etc.), otherwise advertizers would just use it to spam.
[^only-professional-comms]: I'm talking here about person-to-person communication in a professional setting - not personal communication, and not the kinds of "status-change notifications" that monitoring systems emit. Do _not_ apply these strategies to messages from friends and family, or notifications that your service is crashing in production, or that your credit card has been used without your knowledge!
[^no-really-only-professional-comms]: Again, note that I'm talking about _person-to-person_ communication - if your pager goes off because your service is down, you answer it!
[^one-to-ones]: You _are_ having regular one-to-ones with your team, right?
[^email-culture]: Such as in [this thread](https://twitter.com/jacksquaredson/status/1580360715432361985) - linking to the end, scroll back to the top.
[^timezone-adaptation]: Sure, tools could take care of this for you - "_It looks like you're trying to send to someone in a different timezone. Would you like to delay it?_". That mitigates the cognitive overhead aspect (though not entirely - it might have my timezone wrong, or I might just be working odd hours this week), but not the key point that **delaying does no good, and some possible harm**.
[^not-hypocritical]: And please note that I'm not being hypocritical by advocating against "delayed send" here, while previously advocating for urgency metadata. Delayed send is a fundamentally different thing - it _reduces_ recipient choice by _preventing_ you from reading the message even if you would have wanted to. Urgency metadata is another dimension on which recipients can set preferences, but the experience is still ultimately fully controlled by the recipient: as it always should be in personal computing communication situations (**looking at you, advertizers**. You know what they call communication that gets put in front of you without you requesting it? Spam).
[^write-shit-down]: To say nothing of the long potential rant I could go on about how _writing things down, in a clearly-understandable way, in a persistent discoverable location_ is one of the most important skills for any senior knowledge-worker...
[^overtime-exists]: I'm not naïve - I know that I've described an idealized situation, and there are times even at the best companies when you're going to be asked to work overtime. It happens. The point is that is should be considered as an exceptional circumstance caused by a failure of planning, and that you are doing a favour by saving someone else's ass. If it happens more than two or three times in a year, or if there isn't compensation like unofficial time off, that's a red flag that your goodwill is being exploited to cover someone else's mistakes.